==> DateTime-Locale-1.16.tar.gz: DateTime-Locale-1.16/share/ro-MD.pl <==
{
  am_pm_abbreviated => [
    "a.m.",
    "p.m."
  ],
  available_formats => {
    E => "ccc",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM y G",
    GyMMMd => "d MMM y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, dd.MM",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    MMMMEd => "E, d MMMM",
    "MMMMW-count-few" => "'s\N{U+0103}pt\N{U+0103}m\N{U+00e2}na' W 'din' MMM",
    "MMMMW-count-one" => "'s\N{U+0103}pt\N{U+0103}m\N{U+00e2}na' W 'din' MMM",
    "MMMMW-count-other" => "'s\N{U+0103}pt\N{U+0103}m\N{U+00e2}na' W 'din' MMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMdd => "dd.MM",
    Md => "dd.MM",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM.y",
    yMEd => "E, dd.MM.y",
    yMM => "MM.y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "dd.MM.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-few" => "'s\N{U+0103}pt\N{U+0103}m\N{U+00e2}na' w 'din' y",
    "yw-count-one" => "'s\N{U+0103}pt\N{U+0103}m\N{U+00e2}na' w 'din' y",
    "yw-count-other" => "'s\N{U+0103}pt\N{U+0103}m\N{U+00e2}na' w 'din' y"
  },
  code => "ro-MD",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd.MM.y",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "Lun",
    "Mar",
    "Mie",
    "Joi",
    "Vin",
    "S\N{U+00e2}m",
    "Dum"
  ],
  day_format_narrow => [
    "L",
    "Ma",
    "Mi",
    "J",
    "V",
    "S",
    "D"
  ],
  day_format_wide => [
    "luni",
    "mar\N{U+021b}i",
    "miercuri",
    "joi",
    "vineri",
    "s\N{U+00e2}mb\N{U+0103}t\N{U+0103}",
    "duminic\N{U+0103}"
  ],
  day_stand_alone_abbreviated => [
    "Lun",
    "Mar",
    "Mie",
    "Joi",
    "Vin",
    "S\N{U+00e2}m",
    "Dum"
  ],
  day_stand_alone_narrow => [
    "L",
    "Ma",
    "Mi",
    "J",
    "V",
    "S",
    "D"
  ],
  day_stand_alone_wide => [
    "luni",
    "mar\N{U+021b}i",
    "miercuri",
    "joi",
    "vineri",
    "s\N{U+00e2}mb\N{U+0103}t\N{U+0103}",
    "duminic\N{U+0103}"
  ],
  era_abbreviated => [
    "\N{U+00ee}.Hr.",
    "d.Hr."
  ],
  era_narrow => [
    "\N{U+00ee}.Hr.",
    "d.Hr."
  ],
  era_wide => [
    "\N{U+00ee}nainte de Hristos",
    "dup\N{U+0103} Hristos"
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Romanian",
  month_format_abbreviated => [
    "ian.",
    "feb.",
    "mar.",
    "apr.",
    "mai",
    "iun.",
    "iul.",
    "aug.",
    "sept.",
    "oct.",
    "nov.",
    "dec."
  ],
  month_format_narrow => [
    "I",
    "F",
    "M",
    "A",
    "M",
    "I",
    "I",
    "A",
    "S",
    "O",
    "N",
    "D"
  ],
  month_format_wide => [
    "ianuarie",
    "februarie",
    "martie",
    "aprilie",
    "mai",
    "iunie",
    "iulie",
    "august",
    "septembrie",
    "octombrie",
    "noiembrie",
    "decembrie"
  ],
  month_stand_alone_abbreviated => [
    "ian.",
    "feb.",
    "mar.",
    "apr.",
    "mai",
    "iun.",
    "iul.",
    "aug.",
    "sept.",
    "oct.",
    "nov.",
    "dec."
  ],
  month_stand_alone_narrow => [
    "I",
    "F",
    "M",
    "A",
    "M",
    "I",
    "I",
    "A",
    "S",
    "O",
    "N",
    "D"
  ],
  month_stand_alone_wide => [
    "ianuarie",
    "februarie",
    "martie",
    "aprilie",
    "mai",
    "iunie",
    "iulie",
    "august",
    "septembrie",
    "octombrie",
    "noiembrie",
    "decembrie"
  ],
  name => "Romanian Moldova",
  native_language => "rom\N{U+00e2}n\N{U+0103}",
  native_name => "rom\N{U+00e2}n\N{U+0103} Republica Moldova",
  native_script => undef,
  native_territory => "Republica Moldova",
  native_variant => undef,
  quarter_format_abbreviated => [
    "trim. 1",
    "trim. 2",
    "trim. 3",
    "trim. 4"
  ],
  quarter_format_narrow => [
    "I",
    "II",
    "III",
    "IV"
  ],
  quarter_format_wide => [
    "trimestrul 1",
    "trimestrul 2",
    "trimestrul 3",
    "trimestrul 4"
  ],
  quarter_stand_alone_abbreviated => [
    "Trim. 1",
    "Trim. 2",
    "Trim. 3",
    "Trim. 4"
  ],
  quarter_stand_alone_narrow => [
    "I",
    "II",
    "III",
    "IV"
  ],
  quarter_stand_alone_wide => [
    "Trimestrul 1",
    "Trimestrul 2",
    "Trimestrul 3",
    "Trimestrul 4"
  ],
  script => undef,
  territory => "Moldova",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 31
}

==> DateTime-Locale-1.25.tar.gz: DateTime-Locale-1.25/share/ro-MD.pl <==
{
  am_pm_abbreviated => [
    "a.m.",
    "p.m.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM y G",
    GyMMMd => "d MMM y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, dd.MM",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    MMMMEd => "E, d MMMM",
    "MMMMW-count-few" => "'s\N{U+0103}pt\N{U+0103}m\N{U+00e2}na' W 'din' MMMM",
    "MMMMW-count-one" => "'s\N{U+0103}pt\N{U+0103}m\N{U+00e2}na' W 'din' MMMM",
    "MMMMW-count-other" => "'s\N{U+0103}pt\N{U+0103}m\N{U+00e2}na' W 'din' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMdd => "dd.MM",
    Md => "dd.MM",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM.y",
    yMEd => "E, dd.MM.y",
    yMM => "MM.y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "dd.MM.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-few" => "'s\N{U+0103}pt\N{U+0103}m\N{U+00e2}na' w 'din' Y",
    "yw-count-one" => "'s\N{U+0103}pt\N{U+0103}m\N{U+00e2}na' w 'din' Y",
    "yw-count-other" => "'s\N{U+0103}pt\N{U+0103}m\N{U+00e2}na' w 'din' Y",
  },
  code => "ro-MD",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd.MM.y",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "Lun",
    "Mar",
    "Mie",
    "Joi",
    "Vin",
    "S\N{U+00e2}m",
    "Dum",
  ],
  day_format_narrow => [
    "L",
    "Ma",
    "Mi",
    "J",
    "V",
    "S",
    "D",
  ],
  day_format_wide => [
    "luni",
    "mar\N{U+021b}i",
    "miercuri",
    "joi",
    "vineri",
    "s\N{U+00e2}mb\N{U+0103}t\N{U+0103}",
    "duminic\N{U+0103}",
  ],
  day_stand_alone_abbreviated => [
    "Lun",
    "Mar",
    "Mie",
    "Joi",
    "Vin",
    "S\N{U+00e2}m",
    "Dum",
  ],
  day_stand_alone_narrow => [
    "L",
    "Ma",
    "Mi",
    "J",
    "V",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "luni",
    "mar\N{U+021b}i",
    "miercuri",
    "joi",
    "vineri",
    "s\N{U+00e2}mb\N{U+0103}t\N{U+0103}",
    "duminic\N{U+0103}",
  ],
  era_abbreviated => [
    "\N{U+00ee}.Hr.",
    "d.Hr.",
  ],
  era_narrow => [
    "\N{U+00ee}.Hr.",
    "d.Hr.",
  ],
  era_wide => [
    "\N{U+00ee}nainte de Hristos",
    "dup\N{U+0103} Hristos",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Romanian",
  month_format_abbreviated => [
    "ian.",
    "feb.",
    "mar.",
    "apr.",
    "mai",
    "iun.",
    "iul.",
    "aug.",
    "sept.",
    "oct.",
    "nov.",
    "dec.",
  ],
  month_format_narrow => [
    "I",
    "F",
    "M",
    "A",
    "M",
    "I",
    "I",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "ianuarie",
    "februarie",
    "martie",
    "aprilie",
    "mai",
    "iunie",
    "iulie",
    "august",
    "septembrie",
    "octombrie",
    "noiembrie",
    "decembrie",
  ],
  month_stand_alone_abbreviated => [
    "ian.",
    "feb.",
    "mar.",
    "apr.",
    "mai",
    "iun.",
    "iul.",
    "aug.",
    "sept.",
    "oct.",
    "nov.",
    "dec.",
  ],
  month_stand_alone_narrow => [
    "I",
    "F",
    "M",
    "A",
    "M",
    "I",
    "I",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "ianuarie",
    "februarie",
    "martie",
    "aprilie",
    "mai",
    "iunie",
    "iulie",
    "august",
    "septembrie",
    "octombrie",
    "noiembrie",
    "decembrie",
  ],
  name => "Romanian Moldova",
  native_language => "rom\N{U+00e2}n\N{U+0103}",
  native_name => "rom\N{U+00e2}n\N{U+0103} Republica Moldova",
  native_script => undef,
  native_territory => "Republica Moldova",
  native_variant => undef,
  quarter_format_abbreviated => [
    "trim. 1",
    "trim. 2",
    "trim. 3",
    "trim. 4",
  ],
  quarter_format_narrow => [
    "I",
    "II",
    "III",
    "IV",
  ],
  quarter_format_wide => [
    "trimestrul 1",
    "trimestrul 2",
    "trimestrul 3",
    "trimestrul 4",
  ],
  quarter_stand_alone_abbreviated => [
    "Trim. 1",
    "Trim. 2",
    "Trim. 3",
    "Trim. 4",
  ],
  quarter_stand_alone_narrow => [
    "I",
    "II",
    "III",
    "IV",
  ],
  quarter_stand_alone_wide => [
    "Trimestrul 1",
    "Trimestrul 2",
    "Trimestrul 3",
    "Trimestrul 4",
  ],
  script => undef,
  territory => "Moldova",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 36,
}
